==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storagepool/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagepool.kotlin.inputs

import com.pulumi.azurenative.storagepool.inputs.SkuArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Sku for ARM resource
 * @property name Sku name
 * @property tier Sku tier
 */
public data class SkuArgs(
    public val name: Output<String>,
    public val tier: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storagepool.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.storagepool.inputs.SkuArgs =
        com.pulumi.azurenative.storagepool.inputs.SkuArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .tier(tier?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var tier: Output<String>? = null

    /**
     * @param value Sku name
     */
    @JvmName("tfoxsgmyndhfywjd")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Sku tier
     */
    @JvmName("qqqyngwlxymtlbjg")
    public suspend fun tier(`value`: Output<String>) {
        this.tier = value
    }

    /**
     * @param value Sku name
     */
    @JvmName("xvttubeieojschiq")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Sku tier
     */
    @JvmName("ogbjokornkrxvfba")
    public suspend fun tier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tier = tier,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storagepool/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagepool.kotlin.inputs

import com.pulumi.azurenative.storagepool.inputs.SkuArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Sku for ARM resource
 * @property name Sku name
 * @property tier Sku tier
 */
public data class SkuArgs(
    public val name: Output<String>,
    public val tier: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storagepool.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.storagepool.inputs.SkuArgs =
        com.pulumi.azurenative.storagepool.inputs.SkuArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .tier(tier?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var tier: Output<String>? = null

    /**
     * @param value Sku name
     */
    @JvmName("uqxnhjwoihmyhuhv")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Sku tier
     */
    @JvmName("uhurdmyuvmdqnxll")
    public suspend fun tier(`value`: Output<String>) {
        this.tier = value
    }

    /**
     * @param value Sku name
     */
    @JvmName("stbhfuutfolqpxgf")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Sku tier
     */
    @JvmName("owlyqtkqggadappf")
    public suspend fun tier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tier = tier,
    )
}
